import time
from datetime import datetime
import json
from faker import Faker
from confluent_kafka import Producer


def generate_fake_payment():
    fake = Faker()
    payment_data = {
        "transaction_id": fake.uuid4(),
        "timestamp": fake.date_time_this_month(),
        "amount": fake.random_number(digits=5),
        "currency": fake.currency_code(),
        "customer_id": fake.uuid4(),
        "status": fake.random_element(elements=("pending", "completed", "failed"))
    }
    payment_data["timestamp"] = payment_data["timestamp"].strftime("%Y-%m-%d %H:%M:%S")
    return payment_data


def delivery_report(err, msg):
    if err is not None:
        print(f'Message delivery failed: {err}')
    else:
        print(f'Message delivered to {msg.topic()} [{msg.partition()}]')

def produce_to_kafka(topic_name, bootstrap_servers='localhost:9092'):
    producer_conf = {
        'bootstrap.servers': bootstrap_servers,
        'client.id': 'python-producer'
    }

    producer = Producer(producer_conf)

    try:
        while True:
            payment_msg = generate_fake_payment()
            payment_serialized_msg = json.dumps(payment_msg).encode('utf-8')
            producer.produce(topic_name, payment_serialized_msg, callback=delivery_report)
            time.sleep(20)

    except KeyboardInterrupt:
        print("KeyboardInterrupt: Stopping Kafka producer")
    finally:
        producer.flush()
        producer.close()

# Example usage:
if __name__ == "__main__":
    topic_name = "payment_msg"
    produce_to_kafka(topic_name)